/**
 * @file	cgic.h
 *
 * @brief	This library is intended to make the CGI C programmer's life easier, using a set of
 * functions to read fields from HTML forms
 *
 * @author	BlackLight	blacklight86@gmail.com
 * @licence	GPL
 */

#ifndef _CGIC_H
#define _CGIC_H	1

/**
 * @brief	This function is used to set up a header for a HTML page
 * @param	title	The title of the page
 */
void html_header(char *title);

/**
 * @brief	This function is used to close the tags of a HTML page
 */
void html_close();

/**
 * @brief	This function is used to decode the content of a GET or POST query, translating
 * the spaces and the ASCII codes inside of the buffer
 *
 * @param	src	The buffer to decode
 * @param	dest	The destination for the decoded buffer
 * @param	len	The length of the buffer
 */
void unencode(char *src, char *dest, int len);

/**
 * @brief	This function gets the whole content of a GET  query
 */
char* get_get_query();

/**
 * @brief This function gets the whole content of a POST query
 */
char* get_post_query();

/**
 * @brief This function gets the content of a POST or GET form's field
 * @param	query	A string where is saved the content of POST query
 * 				(you can get it with get_post_query() or get_get_query() methods
 * @param	field	The name of the field
 * @example
 * 				<! This is the HTML code >
 * 				<form method="POST" action="/cgi-bin/post.cgi">
 * 					Username: <input name="user">
 * 				</form>
 *
 *				// This is the content of file /cgi-bin/post.cgi.c
 *				char *user,*query;
 *
 *				if ( (query=get_post_query()) == NULL )  {
 *					printf ("Error - invalid form\n");
 *					return;
 *				}
 *
 *				if ( (user=get_field(query,"user")) == NULL )
 *					printf ("Error - invalid field\n");
 *				else
 *					printf ("Welcome %s!\n", user);
 */
char* get_field(char *query, char *field);

#endif

